@@ -90,13 +90,13 @@ sub get {
 						entities2chars => 'Kephra::Edit::Convert::entities2chars()',
 					},
 					comment => {
-						'add-perl' => "Kephra::Edit::Comment::add_block('#')",
-						'del-perl' => "Kephra::Edit::Comment::remove_block('#')",
-						'toggle-perl' => "Kephra::Edit::Comment::toggle_block('#')",
-						'add-c' => "Kephra::Edit::Comment::add_stream( '/*', '*/' )",
-						'del-c' => "Kephra::Edit::Comment::remove_stream( '/*', '*/' )",
-						'add-xml' => "Kephra::Edit::Comment::add_stream( '<!--', '-->' )",
-						'del-xml' => "Kephra::Edit::Comment::remove_stream( '<!--', '-->' )",
+						'add-perl' => "Kephra::Edit::Comment::add_script()",
+						'del-perl' => "Kephra::Edit::Comment::sub_script()",
+						'toggle-perl' => "Kephra::Edit::Comment::toggle_script()",
+						'add-c' => "Kephra::Edit::Comment::add_c( )",
+						'del-c' => "Kephra::Edit::Comment::sub_c( )",
+						'add-xml' => "Kephra::Edit::Comment::add_xml( )",
+						'del-xml' => "Kephra::Edit::Comment::remove_xml( )",
 					},
 					format => {
 						'align-on-begin' => 'Kephra::Edit::Format::align_indent()',
