@@ -65,11 +65,14 @@ sub load {
 sub store {
 	my $file_name = shift;
 	my $config = shift;
+	unless (-w $file_name){
+		my ($volume,$dir,$file) = File::Spec->splitpath( $file_name );
+		$dir = File::Spec->catdir( $volume, $dir );
+		mkdir $dir unless -e $dir;
+	}
 	my $type = _get_type($file_name);
 	if    ($type eq 'conf') { store_conf($file_name, $config) }
 	elsif ($type eq 'yaml') { store_yaml($file_name, $config) }
-#nr_from_file_path
-#	Kephra::File::_remember_save_moment($file_name);
 }
 #
 # API 2 YAML
